About BioSimulators utils — BioSimulators utils 0.1.154 documentation

# About BioSimulators utils

## License

This package is released under the MIT License.

## Development team

This package was developed by the Karr Lab at the Icahn School of Medicine at Mount Sinai and the Center for Reproducible Biomedical Modeling.

## Contributing to BioSimulators utils

We enthusiastically welcome contributions to BioSimulators utils! Please see the guide to contributing and the developer’s code of conduct.

## Acknowledgements

This work was supported by National Institutes of Health award P41EB023912.

## Questions and comments

Please contact the BioSimulators Team with any questions or comments.